@@ -2,15 +2,15 @@
   ==============================================================================
 
    This file is part of the JUCE library.
-   Copyright (c) 2020 - Raw Material Software Limited
+   Copyright (c) 2022 - Raw Material Software Limited
 
    JUCE is an open source library subject to commercial or open-source
    licensing.
 
-   By using JUCE, you agree to the terms of both the JUCE 6 End-User License
-   Agreement and JUCE Privacy Policy (both effective as of the 16th June 2020).
+   By using JUCE, you agree to the terms of both the JUCE 7 End-User License
+   Agreement and JUCE Privacy Policy.
 
-   End User License Agreement: www.juce.com/juce-6-licence
+   End User License Agreement: www.juce.com/juce-7-licence
    Privacy Policy: www.juce.com/juce-privacy-policy
 
    Or: You may also use this code under the terms of the GPL v3 (see
@@ -26,7 +26,7 @@
 namespace juce
 {
 
-class FileChooserDialogBox::ContentComponent  : public Component
+class FileChooserDialogBox::ContentComponent final : public Component
 {
 public:
     ContentComponent (const String& name, const String& desc, FileBrowserComponent& chooser)
@@ -115,7 +115,7 @@ FileChooserDialogBox::FileChooserDialogBox (const String& name,
     if (parentComp != nullptr)
         parentComp->addAndMakeVisible (this);
     else
-        setAlwaysOnTop (juce_areThereAnyAlwaysOnTopWindows());
+        setAlwaysOnTop (WindowUtils::areThereAnyAlwaysOnTopWindows());
 }
 
 FileChooserDialogBox::~FileChooserDialogBox()
@@ -182,28 +182,26 @@ void FileChooserDialogBox::fileDoubleClicked (const File&)
 void FileChooserDialogBox::fileClicked (const File&, const MouseEvent&) {}
 void FileChooserDialogBox::browserRootChanged (const File&) {}
 
-void FileChooserDialogBox::okToOverwriteFileCallback (int result, FileChooserDialogBox* box)
-{
-    if (result != 0 && box != nullptr)
-        box->exitModalState (1);
-}
-
 void FileChooserDialogBox::okButtonPressed()
 {
     if (warnAboutOverwritingExistingFiles
          && content->chooserComponent.isSaveMode()
-         && content->chooserComponent.getSelectedFile(0).exists())
+         && content->chooserComponent.getSelectedFile (0).exists())
     {
-        AlertWindow::showOkCancelBox (MessageBoxIconType::WarningIcon,
-                                      TRANS("File already exists"),
-                                      TRANS("There's already a file called: FLNM")
-                                         .replace ("FLNM", content->chooserComponent.getSelectedFile(0).getFullPathName())
-                                        + "\n\n"
-                                        + TRANS("Are you sure you want to overwrite it?"),
-                                      TRANS("Overwrite"),
-                                      TRANS("Cancel"),
-                                      this,
-                                      ModalCallbackFunction::forComponent (okToOverwriteFileCallback, this));
+        auto options = MessageBoxOptions::makeOptionsOkCancel (MessageBoxIconType::WarningIcon,
+                                                               TRANS ("File already exists"),
+                                                               TRANS ("There's already a file called: FLNM")
+                                                                  .replace ("FLNM", content->chooserComponent.getSelectedFile (0).getFullPathName())
+                                                                 + "\n\n"
+                                                                 + TRANS ("Are you sure you want to overwrite it?"),
+                                                               TRANS ("Overwrite"),
+                                                               TRANS ("Cancel"),
+                                                               this);
+        messageBox = AlertWindow::showScopedAsync (options, [this] (int result)
+        {
+            if (result != 0)
+                exitModalState (1);
+        });
     }
     else
     {
@@ -227,13 +225,13 @@ void FileChooserDialogBox::createNewFolder()
 
     if (parent.isDirectory())
     {
-        auto* aw = new AlertWindow (TRANS("New Folder"),
-                                    TRANS("Please enter the name for the folder"),
+        auto* aw = new AlertWindow (TRANS ("New Folder"),
+                                    TRANS ("Please enter the name for the folder"),
                                     MessageBoxIconType::NoIcon, this);
 
         aw->addTextEditor ("Folder Name", String(), String(), false);
-        aw->addButton (TRANS("Create Folder"), 1, KeyPress (KeyPress::returnKey));
-        aw->addButton (TRANS("Cancel"),        0, KeyPress (KeyPress::escapeKey));
+        aw->addButton (TRANS ("Create Folder"), 1, KeyPress (KeyPress::returnKey));
+        aw->addButton (TRANS ("Cancel"),        0, KeyPress (KeyPress::escapeKey));
 
         aw->enterModalState (true,
                              ModalCallbackFunction::forComponent (createNewFolderCallback, this,
@@ -251,9 +249,12 @@ void FileChooserDialogBox::createNewFolderConfirmed (const String& nameFromDialo
         auto parent = content->chooserComponent.getRoot();
 
         if (! parent.getChildFile (name).createDirectory())
-            AlertWindow::showMessageBoxAsync (MessageBoxIconType::WarningIcon,
-                                              TRANS ("New Folder"),
-                                              TRANS ("Couldn't create the folder!"));
+        {
+            auto options = MessageBoxOptions::makeOptionsOk (MessageBoxIconType::WarningIcon,
+                                                             TRANS ("New Folder"),
+                                                             TRANS ("Couldn't create the folder!"));
+            messageBox = AlertWindow::showScopedAsync (options, nullptr);
+        }
 
         content->chooserComponent.refresh();
     }
